@@ -11,8 +11,9 @@ use subs (
     qw( walkoptree_simple walkoptree_filtered ),
     qw( walkallops_simple walkallops_filtered ),
     qw( opgrep op_or ),
-    qw( croak carp )
 );
+sub croak (@);
+sub carp (@);
 
 use Scalar::Util qw( weaken blessed );
 
@@ -20,13 +21,34 @@ use Scalar::Util qw( weaken blessed );
 
 B::Utils - Helper functions for op tree manipulation
 
+=cut
+
+
+# NOTE: The pod/code version here and in README are computer checked
+# by xt/version.t. Keep them in sync.
+
 =head1 VERSION
 
-0.07
+0.13
 
 =cut
 
-$VERSION = '0.07';
+$VERSION = '0.13';
+
+
+
+=head1 INSTALLATION
+
+To install this module, run the following commands:
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+=cut
+
+
 
 use base 'DynaLoader';
 bootstrap B::Utils $VERSION;
@@ -61,12 +83,12 @@ BEGIN {
     # Fake up a TRACE constant and set $TRACE_FH
     BEGIN { $^W = 0 }
     no warnings;
-    eval 'sub TRACE () {' . ( 0 + $ENV{B_UTILS_TRACE} ) . '}';
+    eval 'sub _TRACE () {' . ( 0 + $ENV{B_UTILS_TRACE} ) . '}';
     die $@ if $@;
     $TRACE_FH ||= \*STDOUT;
 }
-sub TRUE ()  { !!1 }
-sub FALSE () { !!0 }
+sub _TRUE ()  { !!1 }
+sub _FALSE () { !!0 }
 
 =head1 OP METHODS
 
@@ -239,12 +261,17 @@ younger/closer siblings to older/farther siblings.
 =cut
 
 sub B::OP::siblings {
-    my @siblings = shift;
+    my @siblings = $_[0];
 
     my $sibling;
-    push @siblings, $sibling while $sibling = $siblings[-1]->can('sibling');
+    push @siblings, $siblings[-1]->sibling while $siblings[-1]->can('sibling');
     shift @siblings;
-    pop @siblings if 'NULL' eq class $siblings[-1];
+
+    # Remove any undefined or B::NULL objects
+    pop @siblings while
+        @siblings
+        && !( defined $siblings[-1]
+              && ${$siblings[-1]} );
 
     return @siblings;
 }
@@ -268,7 +295,7 @@ Like C< $op-E<gt>next >, but not quite.
 ##         unless ( defined $node ) {
 ##             # If I've been asked to search nothing, just return. The
 ##             # ->parent call might do this to me.
-##             return FALSE;
+##             return _FALSE;
 ##         }
 ##         elsif ( exists $deadend{$node} ) {
 ##             # If this node has been seen already, try again as its
@@ -296,8 +323,8 @@ Like C< $op-E<gt>next >, but not quite.
 ##           for @kids;
 ##
 ##         # Not in this subtree.
-##         $deadend{$node} = TRUE;
-##         return FALSE;
+##         $deadend{$node} = _TRUE;
+##         return _FALSE;
 ##     };
 ##
 ##     my $next = $target;
@@ -307,7 +334,7 @@ Like C< $op-E<gt>next >, but not quite.
 ##           and return $result;
 ##     }
 ##
-##     return FALSE;
+##     return _FALSE;
 ## }
 
 =item C<$op-E<gt>stringify>
@@ -438,10 +465,10 @@ function.
 
 =cut
 
-my $subs_cached = FALSE;
+my $subs_cached = _FALSE;
 
 sub recalc_sub_cache {
-    $subs_cached = FALSE;
+    $subs_cached = _FALSE;
 
     %starts = %roots = @anon_subs = ();
 
@@ -464,9 +491,9 @@ sub _init_sub_cache {
         _B_Utils_init_sub_cache => sub {
 
             # Do not eat our own children!
-            $_[0] eq "$_\::" && return FALSE for @bad_stashes;
+            $_[0] eq "$_\::" && return _FALSE for @bad_stashes;
 
-            return TRUE;
+            return _TRUE;
         },
         ''
     );
@@ -484,7 +511,7 @@ sub _init_sub_cache {
         ),
         main_cv()->PADLIST->ARRAY->ARRAY );
 
-    $subs_cached = TRUE;
+    $subs_cached = _TRUE;
     return;
 }
 
@@ -529,7 +556,7 @@ sub B::GV::_B_Utils_init_sub_cache {
     $starts{$name} = $start;
     $roots{$name}  = $root;
 
-    #    return TRUE;
+    #    return _TRUE;
     return;
 }
 
@@ -540,7 +567,7 @@ sub B::GV::_B_Utils_init_sub_cache {
 #
 #     # JJ: I'm not sure why this callback function exists.
 #
-#     return TRUE;
+#     return _TRUE;
 # }
 
 =item C<walkoptree_simple($op, \&callback, [$data])>
@@ -566,7 +593,7 @@ sub walkoptree_simple {
 
     _walkoptree_simple( {}, @_ );
 
-    return TRUE;
+    return _TRUE;
 }
 
 sub _walkoptree_simple {
@@ -606,7 +633,7 @@ sub walkoptree_filtered {
 
     _walkoptree_filtered( {}, @_ );;
 
-    return TRUE;
+    return _TRUE;
 }
 
 sub _walkoptree_filtered {
@@ -634,7 +661,7 @@ sub _walkoptree_filtered {
         }
     }
 
-    return TRUE;
+    return _TRUE;
 }
 
 =item C<walkallops_simple(\&callback, [$data])>
@@ -651,7 +678,7 @@ sub walkallops_simple {
 
     &_walkallops_simple;
 
-    return TRUE;
+    return _TRUE;
 }
 
 sub _walkallops_simple {
@@ -664,7 +691,7 @@ sub _walkallops_simple {
     $sub = "__ANON__";
     walkoptree_simple( $_->{root}, $callback, $data ) for @anon_subs;
 
-    return TRUE;
+    return _TRUE;
 }
 
 =item C<walkallops_filtered(\&filter, \&callback, [$data])>
@@ -678,7 +705,7 @@ sub walkallops_filtered {
 
     &_walkallops_filterd;
 
-    return TRUE;
+    return _TRUE;
 }
 
 sub _walkallops_filtered {
@@ -693,7 +720,7 @@ sub _walkallops_filtered {
     walkoptree_filtered( $_->{root}, $filter, $callback, $data )
         for @anon_subs;
 
-    return TRUE;
+    return _TRUE;
 }
 
 =item C<opgrep(\%conditions, @ops)>
@@ -836,7 +863,7 @@ CONDITION:
 
             # special disjunction case. undef in a disjunction => (child) does not exist
             if (not defined $condition) {
-                return TRUE if not defined $op and not wantarray();
+                return _TRUE if not defined $op and not wantarray();
                 return();
             }
 
@@ -956,7 +983,7 @@ CONDITION:
                 last;
             }
             elsif ( defined wantarray ) {
-                return TRUE;
+                return _TRUE;
             }
         } # end for @conditions
         # end of conditions loop should be end of op test
@@ -1038,15 +1065,16 @@ sub op_or {
   return({ disjunction => [@conditions] });
 }
 
-sub op_pattern_match {
-  my $op = shift;
-  my $pattern = shift;
-
-  my $ret = {};
-
-  
-  return $ret;
-}
+# TODO
+# sub op_pattern_match {
+#   my $op = shift;
+#   my $pattern = shift;
+# 
+#   my $ret = {};
+# 
+#   
+#   return $ret;
+# }
 
 =item C<carp(@args)>
 
@@ -1100,7 +1128,7 @@ Originally written by Simon Cozens, C<simon@cpan.org>
 Maintained by Joshua ben Jore, C<jjore@cpan.org>
 
 Contributions from Mattia Barbon, Jim Cromie, Steffen Mueller, and
-Chia-liang Kao.
+Chia-liang Kao, Alexandr Ciornii.
 
 =head1 LICENSE
 
